==> Bundle-PDF-0.02.tar.gz: Bundle-PDF-0.02/lib/Bundle/PDF.pm <==
package Bundle::PDF;


our $VERSION = '0.02';



1;
__END__

=head1 NAME

Bundle::PDF - A bundle to install PDF modules and dependencies

=head1 SYNOPSIS

  C<perl -MCPAN -e 'install Bundle::PDF'>

=head1 CONTENTS

PDF

Text::Roman

PDF::API2

Compress::Zlib

File::Copy

Getopt::Long

UNIVERSAL::isa

version

Error

Graphics::ColorNames

Image::Size

LWP::Simple

List::Util

PDF::Writer

XML::Twig

XML::Clean

HTML::Tidy

XML::Simple

Number::Format

XML::Parser

PDF::FromHTML

PDF::Report

PDF::ReportWriter

PDF::Create

Test::More

IO::Scalar

PDF::Labels

PDF::Reuse

PDF::Reuse::Tutorial

PDF::Reuse::Barcode

CAM::PDF

Exporter

Autoloader

Text::PDF

Crypt::RC4

Digest::MD5

File::Temp

IO::All

IPC::Open2

GD

GD::Barcode

Pod::Parser

AppConfig

Parse::RecDescent

Class::MethodMaker

PDF::EasyPDF

PDF::Tk

PDF::Extract

PDF::Table

PDF::API2::Simple

PDF::FDF::Simple

PDF::Xtract

Module::Load

Test::Prereq

Net::FTP

Test::PDF

Business::ReportWriter

XML::Handler::YAWriter

XML::Parser::PerlSAX

PDF::Maki

POSIX

Pod::Pdf

ETL::Pequel

RTF::HTMLConverter

MP3::Info

HTML::TreeBuilder

File::MMagic::XS

File::Extract

Test::Pod

Test::Pod::Coverage

HTML::Parser

HTML::Tagset

HTML::HTMLDoc

Image::ExifTool

URI::Title

Webservice::Trynt::PDF

URI

Module::Pluggable

File::Type

File::Copy

Pod::HtmlPsPdf

DocSet

DBIx::ReportBuilder

DBIx::SearchBuilder

GD::Graph

Chart::Math::Axis

MIME::Base64

GD::Text

IO::File

Archive::Zip

OpenOffice::OOBuilder

















=head2 Description

PDF::CreateSimple was left out because of compilation problems. 
PDF::Template was left out because it requires the third-party
PDFLib-Lite.


=head1 SEE ALSO

For PDFLib-Lite. see www.pdflib.com

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2006 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

==> Bundle-PDF-0.03.tar.gz: Bundle-PDF-0.03/lib/Bundle/PDF.pm <==
package Bundle::PDF;


our $VERSION = '0.03';



1;
__END__;

=head1 NAME

Bundle::PDF - A bundle to install PDF modules and dependencies

=head1 SYNOPSIS

  C<perl -MCPAN -e 'install Bundle::PDF'>

=head1 CONTENTS

PDF

Text::Roman

PDF::API2

Compress::Zlib

File::Copy

Getopt::Long

UNIVERSAL::isa

version

Error

Graphics::ColorNames

Image::Size

LWP::Simple

List::Util

PDF::Writer

XML::Twig

XML::Clean

HTML::Tidy

XML::Simple

Number::Format

XML::Parser

PDF::FromHTML

PDF::Report

PDF::ReportWriter

PDF::Create

Test::More

IO::Scalar

PDF::Labels

PDF::Reuse

PDF::Reuse::Tutorial

PDF::Reuse::Barcode

CAM::PDF

Exporter

AutoLoader

Text::PDF

Crypt::RC4

Digest::MD5

File::Temp

IO::All

IPC::Open2

GD

GD::Barcode

Pod::Parser

AppConfig

Parse::RecDescent

Class::MethodMaker

PDF::EasyPDF

PDF::Tk

PDF::Extract

PDF::Table

PDF::API2::Simple

PDF::FDF::Simple

PDF::Xtract

Module::Load

Test::Prereq

Net::FTP

Test::PDF

Business::ReportWriter

XML::Handler::YAWriter

XML::Parser::PerlSAX

PDF::Maki

POSIX

Pod::Pdf

ETL::Pequel

RTF::HTMLConverter

MP3::Info

HTML::TreeBuilder

File::MMagic::XS

File::Extract

Test::Pod

Test::Pod::Coverage

HTML::Parser

HTML::Tagset

HTML::HTMLDoc

Image::ExifTool

URI::Title

Webservice::Trynt::PDF

URI

Module::Pluggable

File::Type

File::Copy

Pod::HtmlPsPdf

DocSet

DBIx::ReportBuilder

DBIx::SearchBuilder

GD::Graph

Chart::Math::Axis

MIME::Base64

GD::Text

IO::File

Archive::Zip

OpenOffice::OOBuilder

Font::TTF

Algorithm::Diff

Font::TTFMetrics

SWF::File

SWF::Chart

SWF::Search

SWF::Builder

SWF::Header

SWF::NeedsRecompile

FLV::Info

File::Headerinfo::SWF

File::Binary

IO::Handle

IO::File

Font::AFM

Sys::Hostname

Text::CSV_XS

PostScript::Document

PostScript::MailLabels

PostScript::CDCover

PostScript::File

PostScript::Graph

PostScript::Columns

PostScript::EPSF

PostScript::Font

PostScript::Simple

PostScript::Simple::Table

RPC::JSON

MP3::Info

File::Spec

Exporter::Lite

Class::Accessor













=head2 Description

PDF::CreateSimple was left out because of compilation problems. 
PDF::Template was left out because it requires the third-party
PDFLib-Lite.


=head1 SEE ALSO

For PDFLib-Lite. see www.pdflib.com

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut
